setwd("/home/milos/Dropbox/Радови/Научни радови/Phengaris teleius/Behavior/Supplementary Material 1")
t <- read.csv("Behavior - tracking study 2016.csv")
m <- read.csv("Behavior - MRR study.csv")

library(lme4)
library(emmeans)

##################################################
# Get the time in sec of butterfly behavior events
##################################################
time_in_seconds <- function(tabela) {
  individual = "-1"
  output <- vector(length = nrow(tabela))
  previous_time = 0
  for (i in 1:nrow(tabela)) {
    if (tabela[i, ]$IndividualNo != individual) {
      # New individual
      hms <- strsplit(tabela[i, ]$BehaviorTime, split = ":")
      seconds <- (as.numeric(hms[[1]][1]) * 3600) + 
        (as.numeric(hms[[1]][2]) * 60) +
        (as.numeric(hms[[1]][3]))
      if (i == 1) {
        # Don't do anything!
      } else {
        output[i - 1] <- 300 - previous_time
      }
      #print(paste0("New individual: ", seconds))
      previous_time <- 0
      individual = tabela[i,]$IndividualNo
    } else {
      # Already processed individual
      hms <- strsplit(tabela[i, ]$BehaviorTime, split = ":")
      seconds <- (as.numeric(hms[[1]][1]) * 3600) + 
        (as.numeric(hms[[1]][2]) * 60) +
        (as.numeric(hms[[1]][3]))
      real_length <- seconds - previous_time
      previous_time <- previous_time + real_length
      if (i == nrow(tabela)) {
        output[i - 1] <- real_length
        output[i] <- 300 - previous_time
      } else {
        output[i - 1] <- real_length
      }
      #print(paste0("Individual is the same: ", seconds))
    }
  }
  return(output)
}

t$BehaviourTimeSec <- time_in_seconds(t)

# Remove first and last observation to exclude bias in time of behavior
# since behavior could start before individual has been observed, and continue
# after 5 minutes elapsed...
t <- t[duplicated(t$IndividualNo, fromLast = T), ]
t <- t[duplicated(t$IndividualNo, fromLast = F), ]

# Remove data from the unmown meadow since the sample size was too low
# for detailed analysis
t <- t[t$Habitat == "Unmown meadow", ]

##################################################
# MRR dataset
##################################################

# Plant species ##################################

# Plant species used for feeding/resting
round(prop.table(table(m[m$Behavior == "feed" & m$Sex == "female" & m$Object != "", "Object"])), digits = 4)
round(prop.table(table(m[m$Behavior == "feed" & m$Sex == "male" & m$Object != "", "Object"])), digits = 4)
round(prop.table(table(m[m$Behavior == "rest" & m$Sex == "female" & m$Object != "", "Object"])), digits = 4)
round(prop.table(table(m[m$Behavior == "rest" & m$Sex == "male" & m$Object != "", "Object"])), digits = 4)
sort(names(table(m[m$Behavior == "feed" & m$Sex == "male" & m$Object != "", "Object"])))
sort(names(table(m[m$Behavior == "rest" & m$Object != "", "Object"])))
# Plant species used for feeding/resting in males and females separately
sort(names(table(m[m$Behavior == "feed" & m$Sex == "female" & m$Object != "" & m$Object != "snail", "Object"])))
sort(names(table(m[m$Behavior == "feed" & m$Sex == "male" & m$Object != "" & m$Object != "snail", "Object"])))
sort(names(table(m[m$Behavior == "rest" & m$Sex == "female" & m$Object != "" & m$Object != "snail", "Object"])))
sort(names(table(m[m$Behavior == "rest" & m$Sex == "male" & m$Object != "" & m$Object != "snail", "Object"])))

# Binomial model - differences between males/females in plant feeding usage
m.feed <- m[m$Sex != "" & m$PlantGroups != "" & m$Behavior == "feed", ]
m.feed[m.feed$PlantGroups == "Fabaceae",]$PlantGroups <- "Other"
m.feed[m.feed$PlantGroups == "Lamiaceae",]$PlantGroups <- "Other"
m.feed[m.feed$PlantGroups == "Onagraceae",]$PlantGroups <- "Other"
m.feed[m.feed$PlantGroups == "Plantaginaceae",]$PlantGroups <- "Other"
m.feed$Sex <- as.factor(m.feed$Sex)
m.feed$PlantGroups <- as.factor(m.feed$PlantGroups)
rbind(table(m.feed[m.feed$Sex == "female", ]$PlantGroups), table(m.feed[m.feed$Sex == "male", ]$PlantGroups))
m.feed.glm <- glm(Sex ~ 0 + PlantGroups, data = m.feed, family = binomial)
summary(m.feed.glm)
m.feed.em <- emmeans(m.feed.glm, pairwise ~ PlantGroups, type = "response")
m.feed.em
plot(m.feed.em)

# Binomial model - differences between males/females in plant resting usage
m.rest <- m[m$Sex != "" & m$PlantGroups != "" & m$Behavior == "rest", ]
table(m.rest$PlantGroups)
m.rest[m.rest$PlantGroups == "Fabaceae",]$PlantGroups <- "Other"
m.rest[m.rest$PlantGroups == "Lamiaceae",]$PlantGroups <- "Other"
m.rest[m.rest$PlantGroups == "Onagraceae",]$PlantGroups <- "Other"
m.rest[m.rest$PlantGroups == "Plantaginaceae",]$PlantGroups <- "Other"
m.rest[m.rest$PlantGroups == "Caryophilaceae",]$PlantGroups <- "Other"
m.rest[m.rest$PlantGroups == "Equisetum",]$PlantGroups <- "Other"
m.rest$Sex <- as.factor(m.rest$Sex)
m.rest$PlantGroups <- as.factor(m.rest$PlantGroups)
rbind(table(m.rest[m.rest$Sex == "female", ]$PlantGroups), table(m.rest[m.rest$Sex == "male", ]$PlantGroups))
m.rest.glm <- glm(Sex ~ 0 + PlantGroups, data = m.rest, family = binomial)
summary(m.rest.glm)
m.rest.em <- emmeans(m.rest.glm, pairwise ~ PlantGroups, type = "response")
m.rest.em
plot(m.rest.em)

# Plant color ##################################

# Group some colors in logical gropus
table(m$Color)
m[m$Color == "white", ]$Color <- "white-yellow"
m[m$Color == "yellow", ]$Color <- "white-yellow"
m[m$Color == "pink", ]$Color <- "pink-purple"
m[m$Color == "purple", ]$Color <- "pink-purple"
m[m$Color == "ochre", ]$Color <- "ochre-brown"
m[m$Color == "brown", ]$Color <- "ochre-brown"
m[m$Color == "blue", ]$Color <- "blue-green"
m[m$Color == "green", ]$Color <- "blue-green"

# Color of plants used for feeding
m.color.feed <- m[m$Sex != "" & m$Color != "" & m$Behavior == "feed", ]
table(m.color.feed$Color)
m.color.feed[m.color.feed$Color == "blue-green", ]$Color <- "Other"
m.color.feed[m.color.feed$Color == "ochre-brown", ]$Color <- "Other"
m.color.feed[m.color.feed$Color == "white-yellow", ]$Color <- "Other"
m.color.feed$Color <- as.factor(m.color.feed$Color)
m.color.feed$Sex <- as.factor(m.color.feed$Sex)
rbind(table(m.color.feed[m.color.feed$Sex == "female", ]$Color), table(m.color.feed[m.color.feed$Sex == "male", ]$Color))
m.color.feed.glm <- glm(Sex ~ 0 + Color, data = m.color.feed, family = binomial)
summary(m.color.feed.glm)
m.color.feed.em <- emmeans(m.color.feed.glm, pairwise ~ Color, type = "response")
m.color.feed.em

# Color of plants used for resting
m.color.rest <- m[m$Sex != "" & m$Color != "" & m$Behavior == "rest", ]
table(m.color.rest$Color)
m.color.rest$Color <- as.factor(m.color.rest$Color)
m.color.rest$Sex <- as.factor(m.color.rest$Sex)
rbind(table(m.color.rest[m.color.rest$Sex == "female", ]$Color), table(m.color.rest[m.color.rest$Sex == "male", ]$Color))
m.color.rest.glm <- glm(Sex ~ 0 + Color, data = m.color.rest, family = binomial)
summary(m.color.rest.glm)
m.color.rest.em <- emmeans(m.color.rest.glm, pairwise ~ Color, type = "response")
m.color.rest.em

# Plant shape ##################################

table(m$Shape)
m[m$Shape == "bell", ]$Shape <- "oval"
m[m$Shape == "disk", ]$Shape <- "oval"
m[m$Shape == "corymb", ]$Shape <- "capitulum"
m[m$Shape == "zygomorphic", ]$Shape <- "irregular"

# Shape of plants used for feeding
m.shape.feed <- m[m$Sex != "" & m$Shape != "" & m$Behavior == "feed", ]
table(m.shape.feed$Shape)
m.shape.feed$Shape <- as.factor(m.shape.feed$Shape)
m.shape.feed$Sex <- as.factor(m.shape.feed$Sex)
rbind(table(m.shape.feed[m.shape.feed$Sex == "female", ]$Shape), table(m.shape.feed[m.shape.feed$Sex == "male", ]$Shape))
m.shape.feed.glm <- glm(Sex ~ 0 + Shape, data = m.shape.feed, family = binomial)
summary(m.shape.feed.glm)
m.shape.feed.em <- emmeans(m.shape.feed.glm, pairwise ~ Shape, type = "response")
m.shape.feed.em

# Shape of plants used for resting
m.shape.rest <- m[m$Sex != "" & m$Shape != "" & m$Behavior == "rest", ]
table(m.shape.rest$Shape)
m.shape.rest$Shape <- as.factor(m.shape.rest$Shape)
m.shape.rest$Sex <- as.factor(m.shape.rest$Sex)
rbind(table(m.shape.rest[m.shape.rest$Sex == "female", ]$Shape), table(m.shape.rest[m.shape.rest$Sex == "male", ]$Shape))
m.shape.rest.glm <- glm(Sex ~ 0 + Shape, data = m.shape.rest, family = binomial)
summary(m.shape.rest.glm)
m.shape.rest.em <- emmeans(m.shape.rest.glm, pairwise ~ Shape, type = "response")
m.shape.rest.em

##################################################
# Tracking dataset
##################################################


# Flight time ####################################
##############################################

# Comparing time spent flying between sexes, habitats and localities
t.flight <- t[t$Behavior == "flight", ]

t.flight.fit <- glmer(BehaviourTimeSec ~ 1 + Sex * Locality + (1|IndividualNo), data = t.flight, family = poisson) # AIC 4845.0
t.flight.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + Locality + (1|IndividualNo), data = t.flight, family = poisson) # AIC 4844.8
t.flight.fit <- glmer(BehaviourTimeSec ~ 1 + Locality + (1|IndividualNo), data = t.flight, family = poisson) # AIC 4852.0
t.flight.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + (1|IndividualNo), data = t.flight, family = poisson) # AIC 4844.5
summary(t.flight.fit)

emmeans(t.flight.fit, pairwise ~ Sex, type = "response")

# Interactions ###################################
##############################################

# Part 1. Overall comparison of times spent interacting
t.inter <- t[t$Behavior == "interaction", ]
# Check the sample size at Ludaš locality
table(t.inter[t.inter$Locality == "Ludash", ]$Sex) # Females were undersampled here

t.inter1.fit <- glmer(BehaviourTimeSec ~ 1 + Sex * Locality + (1|IndividualNo), data = t.inter, family = poisson) # AIC 1000.4
t.inter1.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + (1|Locality) + (1|IndividualNo), data = t.inter, family = poisson) # AIC 705.4 Locality singualr, var = 0
t.inter1.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + Locality + (1|IndividualNo), data = t.inter, family = poisson) # AIC 1000.4
t.inter1.fit <- glmer(BehaviourTimeSec ~ 1 + Locality + (1|IndividualNo), data = t.inter, family = poisson) # AIC 1004.4
t.inter1.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + (1|IndividualNo), data = t.inter, family = poisson) # AIC 999.2
summary(t.inter1.fit)
emmeans(t.inter1.fit, pairwise ~ Sex, type = "response")

# Part 2. Checking if interaction between different species last shorter
t.inter <- t.inter[t.inter$Object != "", ]
t.inter$SameSpecies <- "Different species"
t.inter[t.inter$Species == "Phengaris teleius" & t.inter$Object == "Phengaris teleius", ]$SameSpecies <- "Same species"
# Check the sample size
table(t.inter$SameSpecies) # n = 8 for different species, i.e. 10.52% of all the interactions
table(t.inter[t.inter$SameSpecies == "Different species", ]$Object) # 5 interaction with butterfleis and 3 with other insects

t.inter.fit <- glmer(BehaviourTimeSec ~ 1 + SameSpecies + Locality + (1|IndividualNo), data = t.inter, family = poisson) # AIC 680.0
t.inter.fit <- glmer(BehaviourTimeSec ~ 1 + SameSpecies + (1|IndividualNo), data = t.inter, family = poisson) # AIC 678.7
summary(t.inter.fit)
emmeans(t.inter.fit, pairwise ~ SameSpecies, type = "response")

# Part 3. Checking if interactions between different sexes last longer
t.inter$SameSex <- NA
t.inter[t.inter$SameSpecies == "Same species" & t.inter$Sex == "male" & t.inter$ObjectDescription == "male", ]$SameSex <- "Same sex"
t.inter[t.inter$SameSpecies == "Same species" & t.inter$Sex == "female" & t.inter$ObjectDescription == "female", ]$SameSex <- "Same sex"
t.inter[t.inter$SameSpecies == "Same species" & t.inter$Sex == "male" & t.inter$ObjectDescription == "female", ]$SameSex <- "Different sex"
t.inter[t.inter$SameSpecies == "Same species" & t.inter$Sex == "female" & t.inter$ObjectDescription == "male", ]$SameSex <- "Different sex"
t.inter.fit <- glmer(BehaviourTimeSec ~ 1 + SameSex + (1|IndividualNo), data = t.inter[t.inter$SameSpecies == "Same species", ], family = poisson) # AIC 562.2
summary(t.inter.fit)
emmeans(t.inter.fit, pairwise ~ SameSex, type = "response")

# Feeding and plan species ########################
###############################################

# Some summary for feeding
round(prop.table(table(t[t$Species == "Phengaris teleius" & t$Sex == "female" & t$Behavior == "feed" & t$Object != "", ]$Object)), digits = 4)
round(prop.table(table(t[t$Species == "Phengaris teleius" & t$Sex == "male" & t$Behavior == "feed" & t$Object != "", ]$Object)), digits = 4)
# ...and some sumarry for resting
round(prop.table(table(t[t$Species == "Phengaris teleius" & t$Sex == "female" & t$Behavior == "rest" & t$Object != "", ]$Object)), digits=4)
round(prop.table(table(t[t$Species == "Phengaris teleius" & t$Sex == "male" & t$Behavior == "rest" & t$Object != "", ]$Object)), digits=4)

# Part 1. Overall feed times, excluding plant species effect
t.feed <- t[t$Behavior == "feed", ]

t.feed.fit <- glmer(BehaviourTimeSec ~ 1 + Sex * Locality + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1769.4
t.feed.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + Locality + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1767.5
t.feed.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1766.7
t.feed.fit <- glmer(BehaviourTimeSec ~ 1 + Locality + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1766.1
summary(t.feed.fit)
emmeans(t.feed.fit, pairwise ~ Locality, type = "response")

# Part 2. S. officinalis vs other species for feeding
t.feed <- t[t$Species == "Phengaris teleius" & t$Behavior == "feed" & t$Object != "" & t$Habitat == "Unmown meadow", ]
prop.table(table(t.feed$Object))
t.feed$Plant <- "Other compositae"
t.feed[t.feed$Object == "Sanguisorba officinalis", ]$Plant <- "Sanguisorba officinalis"
t.feed$Plant <-  relevel(as.factor(t.feed$Plant), "Sanguisorba officinalis")

t.feed.fit <- glmer(Plant ~ Locality * Sex + (1|IndividualNo), data = t.feed, family = binomial) # AIC = 82.7 model failed
t.feed.fit <- glmer(Plant ~ Locality + Sex + (1|IndividualNo), data = t.feed, family = binomial) # AIC = 82.7
t.feed.fit <- glmer(Plant ~ Locality + (1|IndividualNo), data = t.feed, family = binomial) # AIC = 84.7
t.feed.fit <- glmer(Plant ~ Sex + (1|IndividualNo), data = t.feed, family = binomial) # AIC = 84.0
summary(t.feed.fit)
emmeans(t.feed.fit, pairwise ~ Sex, type = "response")

# Comparing feeding times
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Sex * Locality + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1664.4 failed to converge
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant + Sex * Locality + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1667.5
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Locality + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1664.3
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant + Locality + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1667.6
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Sex + Locality + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1663.8
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Locality + Sex + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1663.4
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant + Sex + (1|IndividualNo), data = t.feed, family = poisson) # 1663.6
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Sex + (1|IndividualNo), data = t.feed, family = poisson) # AIC 1661.8
summary(glm.poisson)
emmeans(glm.poisson, pairwise ~ Plant + Sex, type = "response")

# Resting and plan species #########################
###############################################

# Overall resting times, excluding plant species effect
t.rest <- t[t$Behavior == "rest", ]

t.rest.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + Locality + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1486.6
t.rest.fit <- glmer(BehaviourTimeSec ~ 1 + Sex + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1485.8
t.rest.fit <- glmer(BehaviourTimeSec ~ 1 + Locality + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1485.5
t.rest.fit <- glmer(BehaviourTimeSec ~ 1 + Sex * Locality + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1485.5
summary(t.rest.fit)
emmeans(t.rest.fit, pairwise ~ Locality + Sex, type = "response")

# S. officinalis vs other species for resting
t.rest <-  t[t$Species == "Phengaris teleius" & t$Behavior == "rest" & t$Object != "", ]
sort(prop.table(table(t.rest$Object)))
t.rest$Plant <- "Other plants"
t.rest[t.rest$Object == "Sanguisorba officinalis", ]$Plant <- "Sanguisorba officinalis"
t.rest$Plant <-  relevel(as.factor(t.rest$Plant), "Sanguisorba officinalis")
glm.binomial <- glmer(Plant ~ Sex * Locality + (1|IndividualNo), data = t.rest, family = binomial)
summary(glm.binomial)
emmeans(glm.binomial, pairwise ~ Sex + Locality, type = "response")

# Comparing resting times for P. teleius
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Sex + Locality + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1835.0
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant + Sex * Locality + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1828.2
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Locality + Sex + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1829.5
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Sex + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1833.4
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant + Sex + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1831.7
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Locality + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1827.5
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant + Locality + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1831.7
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1829.9
glm.poisson <- glmer(BehaviourTimeSec ~ 1 + Plant * Sex * Locality + (1|IndividualNo), data = t.rest, family = poisson) # AIC 1823.0 BEST
summary(glm.poisson)
emmeans(glm.poisson, pairwise ~ Plant + Locality + Sex, type = "response")
# Note, the model is very complex and the data is overfit, thus discarding this results is the best option
